using System.IO;

using NAnt.Core;
using NAnt.Core.Attributes;

namespace Nant.VMWare.Tasks
{
    [TaskName( "connect-iso-to-vm" )]
    public class ConnectIsoToVirtualMachineTask : VirtualMachineTask
    {
        [TaskAttribute( "local-path", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string IsoLocalPath { get; set; }

        [TaskAttribute( "remote-path", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string IsoRemotePath { get; set; }

        protected override void ExecuteTask()
        {
            string isoLocalPath = Path.GetFullPath( IsoLocalPath );

            if ( !File.Exists( isoLocalPath ) )
            {
                throw new BuildException( "ISO does not exist at specified location: " + isoLocalPath );
            }

            TestEnvironment.DeployAndConnectIso( isoLocalPath, IsoRemotePath );

            Log( Level.Info, "Uploaded ISO to '{0}' from '{1}'. VM uses uploaded ISO now.", IsoRemotePath, IsoLocalPath );
        }
    }
}