using System.IO;

using NAnt.Core;
using NAnt.Core.Attributes;

namespace Nant.VMWare.Tasks
{
    [TaskName( "copy-files-to-vm" )]
    public class CopyFilesToVirtualMachineTask : VirtualMachineTask
    {
        [TaskAttribute( "source-dir", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string SourceFolder { get; set; }

        [TaskAttribute( "destination-dir", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string DestinationFolder { get; set; }

        protected override void ExecuteTask()
        {
            string sourceFolder = Path.GetFullPath( SourceFolder );

            if ( !Directory.Exists( sourceFolder ) )
            {
                throw new BuildException( "Source folder does not exist: " + sourceFolder );
            }

            TestEnvironment.CopyFiles( sourceFolder, DestinationFolder );

            Log( Level.Info, "Successfully copied files from '{0}' to VM's folder at '{1}'", SourceFolder, DestinationFolder );
        }
    }
}