﻿using System.Diagnostics;
using System.Text;

using NAnt.Core;
using NAnt.Core.Attributes;

namespace Nant.VMWare.Tasks
{
    [TaskName( "run-nunit" )]
    public class RunNunitTask : Task
    {
        private const string RunnerExePropertyName = "nunit.runner.exe";

        [TaskAttribute( "project-file", Required = false )]
        [StringValidator( AllowEmpty = false )]
        public string ProjectFile { get; set; }

        [TaskAttribute( "asembly", Required = false )]
        [StringValidator( AllowEmpty = false )]
        public string Assembly { get; set; }

        [TaskAttribute( "categories", Required = false )]
        [StringValidator( AllowEmpty = false )]
        public string Categories { get; set; }

        [TaskAttribute( "out", Required = false )]
        [StringValidator( AllowEmpty = false )]
        public string TxtFilePath { get; set; }

        [TaskAttribute( "xml", Required = false )]
        [StringValidator( AllowEmpty = false )]
        public string XmlFilePath { get; set; }

        protected override void ExecuteTask()
        {
            if ( !Properties.Contains( RunnerExePropertyName ) )
            {
                throw new BuildException( "Please supply NUnit runner executable location in property: " + RunnerExePropertyName );
            }

            if ( string.IsNullOrEmpty( ProjectFile ) && string.IsNullOrEmpty( Assembly ) )
            {
                throw new BuildException( "Please supply a project or an assembly" );
            }

            StringBuilder args = new StringBuilder( " /labels" );

            if ( !string.IsNullOrEmpty( TxtFilePath ) )
            {
                args.Append( " /out=\"" + TxtFilePath + "\"" );
            }

            if ( !string.IsNullOrEmpty( XmlFilePath ) )
            {
                args.Append( " /xml=\"" + XmlFilePath + "\"" );
            }

            if ( !string.IsNullOrEmpty( Categories ) )
            {
                args.Append( " /include=" + Categories + " " );
            }

            if ( !string.IsNullOrEmpty( ProjectFile ) )
            {
                args.Append( " \"" + ProjectFile + "\"" );
            }
            else
            {
                args.Append( " \"" + Assembly + "\"" );
            }

            Process process = new Process
                                  {
                                      StartInfo = new ProcessStartInfo( Properties[ RunnerExePropertyName ], args.ToString() )
                                                      {
                                                          CreateNoWindow = true,
                                                          UseShellExecute = false,
                                                          WorkingDirectory = Project.BaseDirectory,
                                                          RedirectStandardError = true,
                                                          RedirectStandardInput = true,
                                                          RedirectStandardOutput = true
                                                      }
                                  };

            process.Start();

            Log( Level.Info, "" );
            Log( Level.Info, "Started with arguments: " + process.StartInfo.Arguments );
            Log( Level.Info, process.StandardOutput.ReadToEnd() );

            if ( process.ExitCode != 0 )
            {
                Log( Level.Error, process.StandardError.ReadToEnd() );
                throw new BuildException( "NUnit failed" );
            }
        }
    }
}