using System;

using NAnt.Core;
using NAnt.Core.Attributes;

namespace Nant.VMWare.Tasks
{
    [TaskName( "run-exe-in-vm" )]
    public class RunProgramInVirtualMachineTask : VirtualMachineTask
    {
        [TaskAttribute( "path", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string ExeLocation { get; set; }

        [TaskAttribute( "args", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string Arguments { get; set; }

        [TaskAttribute( "wait-for-exit", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string WaitForExit { get; set; }

        protected override void ExecuteTask()
        {
            bool waitForExit;

            if ( !Boolean.TryParse( WaitForExit, out waitForExit ) )
            {
                waitForExit = true;
            }

            Log( Level.Info, "Starting program with arguments: {0} {1}", ExeLocation, Arguments );

            int exitCode = TestEnvironment.RunProcess( ExeLocation, Arguments, waitForExit );

            if ( exitCode != 0 )
            {
                throw new BuildException( "Process exited with code: " + exitCode );
            }
        }
    }
}